package org.codehaus.plexus.interpolation.util;
/*
 * Copyright 2001-2008 Codehaus Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertEquals;

public class StringUtilsTest {
    @Test
    public void testCapitalizeFirstLetter() throws Exception {
        assertEquals("Abc", StringUtils.capitalizeFirstLetter("abc"));
        assertEquals("\u00cdce", StringUtils.capitalizeFirstLetter("\u00edce"));
        assertEquals("X", StringUtils.capitalizeFirstLetter("x"));
    }
}
